# The Linkage Package

This package contains functions useful to link two records together via identifying information. It uses information such as name, DOB, and address with a hash generator to determine if two records are referencing the same patient. 